# encoding: utf-8

# File:	clients/ncpserver_auto.ycp
# Package:	Configuration of ncpserver
# Summary:	Client for autoinstallation
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: ncpserver_auto.ycp,v 1.1.2.1 2004/10/07 18:35:01 sbunch Exp $
#
# This is a client for autoinstallation. It takes its arguments,
# goes through the configuration and return the setting.
# Does not do any changes to the configuration.

# @param function to execute
# @param map/list of ncpserver settings
# @return [Hash] edited settings, Summary or boolean on success depending on called function
# @example map mm = $[ "FAIL_DELAY" : "77" ];
# @example map ret = WFM::CallFunction ("ncpserver_auto", [ "Summary", mm ]);
module Yast
  class NcpserverAutoClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-ncpserver"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Ncpserver auto started")

      Yast.import "Ncpserver"
      Yast.include self, "novell-ncpserver/wizards.rb"

      @ret = nil
      @func = ""
      @param = {}

      # Check arguments
      if Ops.greater_than(Builtins.size(WFM.Args), 0) &&
          Ops.is_string?(WFM.Args(0))
        @func = Convert.to_string(WFM.Args(0))
        if Ops.greater_than(Builtins.size(WFM.Args), 1) &&
            Ops.is_map?(WFM.Args(1))
          @param = Convert.to_map(WFM.Args(1))
        end
      end
      Builtins.y2debug("func=%1", @func)
      Builtins.y2debug("param=%1", @param)

      # Create a summary
      if @func == "Summary"
        @ret = Ops.get_string(Ncpserver.Summary, 0, "")
      # Reset configuration
      elsif @func == "Reset"
        Ncpserver.Import({})
        @ret = {}
      # Change configuration (run AutoSequence)
      elsif @func == "Change"
        @ret = NcpserverAutoSequence()
      # Import configuration
      elsif @func == "Import"
        @ret = Ncpserver.Import(@param)
      # Return actual state
      elsif @func == "Export"
        Ncpserver.Read if Ncpserver.Settings == nil || Ncpserver.Settings == {}
        Ncpserver.auto_clone = true
        @ret = Ncpserver.Export
      # Return needed packages
      elsif @func == "Packages"
        @ret = Ncpserver.AutoPackages
      # Read current state
      elsif @func == "Read"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        @ret = Ncpserver.Read
        Progress.set(@progress_orig)
      # Write givven settings
      elsif @func == "Write"
        Yast.import "Progress"
        @progress_orig = Progress.set(false)
        Ncpserver.write_only = true
        @ret = Ncpserver.Write
        Progress.set(@progress_orig)
      # Return if configuration  was changed
      # return boolean
      elsif @func == "GetModified"
        Ncpserver.globals_configured = true
        @ret = Ncpserver.globals_configured
      # Set modified flag
      # return boolean
      elsif @func == "SetModified"
        Ncpserver.globals_configured = true
        @ret = true
      else
        Builtins.y2error("Unknown function: %1", @func)
        @ret = false
      end

      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Ncpserver auto finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NcpserverAutoClient.new.main
