# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	clients/ncpserver_proposal.ycp
# Package:	Configuration of ncpserver
# Summary:	Proposal function dispatcher.
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: ncpserver_proposal.ycp,v 1.1.2.6 2005/02/10 21:20:32 sbunch Exp $
#
# Proposal function dispatcher for ncpserver configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class NcpserverProposalClient < Client
    def main

      textdomain "novell-ncpserver"

      Yast.import "Ncpserver"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Ncpserver proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        if @force_reset || !Ncpserver.proposal_valid
          Ncpserver.proposal_valid = true
          @progress_orig = Progress.set(false)
          Ncpserver.Read
          Progress.set(@progress_orig)
        end
        @sum = Ncpserver.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("ncpserver", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }
        if !Mode.update && !Mode.autoupgrade
          if Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            ) == "" &&
              Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == "" ||
              Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_PASSWORD",
                ""
              ) == ""
            Ops.set(@ret, "errors", true)
          end
        end
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("NCP Server proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "ncpserver--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "ncpserver", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "ncpserver--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "ncpserver", false)
          @ret = { "workflow_sequence" => :next }
        else
          @stored = Ncpserver.Export
          @seq = Convert.to_symbol(
            WFM.CallFunction("ncpserver", [path(".propose")])
          )
          Ncpserver.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("novell-ncp") # FIXME: is this needed anymore?
        @isSelected = @isSelected &&
          NovellAddonInstall.IsProductSelected("ncpserver")
        Builtins.y2milestone(
          "Proposal:IsSelected:novell-ncp(ncpserver): %1",
          @isSelected
        )
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for Ncpserver in proposals
            "rich_text_title" => _(
              "NetWare Core Protocol (NCP) Server"
            ),
            # Menu title for Ncpserver in proposals
            "menu_title"      => _(
              "Net&Ware Core Protocol (NCP) Server"
            ),
            "id"              => "ncpserver"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        Ncpserver.Write
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Ncpserver proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::NcpserverProposalClient.new.main
