# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	include/novell-ncpserver/dialogs.ycp
# Package:	Configuration of ncpserver
# Summary:	Dialogs definitions
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: dialogs.ycp,v 1.1.2.4 2005/07/29 00:27:13 mclark Exp $
module Yast
  module NovellNcpserverDialogsInclude
    def initialize_novell_ncpserver_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-ncpserver"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "Ncpserver"
      Yast.import "EdirUtils"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"

      Yast.include include_target, "novell-ncpserver/helps.rb"
      Yast.include include_target, "novell-ncpserver/complex.rb"
    end

    def PromptIfNeededForEdirAdminPassword
      useXad = false

      if Ncpserver.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          useXad = true # if this value is set at all, then it is the eDir admin (in spite of xad name)
        end
      end
      Builtins.y2milestone("Ncpserver:use xad:%1", useXad)

      if useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end

      useXad
    end


    # Configure1 dialog
    # @return dialog result
    def EdirHostDialog
      if Mode.update || Mode.autoupgrade
        Popup.Message(NovellUtils.noConfigMessage)
        Builtins.y2milestone(
          "Ncpserver.EdirHostDialog:skipping GUI since we are in upgrade mode."
        )
        return :skip
      end

      # Ncpserver configure1 dialog caption
      caption = _("NCP Server Configuration")

      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      adminName = "" if adminName == nil

      if Ncpserver.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        Builtins.y2milestone(
          "Ncpserver:XAD_TREE_ADMIN_CONTEXT:%1",
          xad_tree_admin_context
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          adminName = NovellUtils.Ldap2Nds(xad_tree_admin_context)
        end
      end
      Builtins.y2milestone("Ncpserver:admin:%1", adminName)

      #  configure1 dialog contents
      contents = HVSquash(
        VBox(
          Label(
            _(
              "This value cannot be edited here.  Please use the LDAP Server Configuration."
            )
          ),
          VSpacing(1),
          TextEntry(
            Id(:adminName),
            _("Admin name with context (e.g. cn=admin,o=microfocus)"),
            adminName
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "c1", ""),
        Label.BackButton,
        Label.NextButton
      )
      UI.ChangeWidget(Id(:adminName), :Enabled, false)

      PromptIfNeededForEdirAdminPassword()

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end
          next if !NovellValidators.ValidateFDN(adminName, false)
          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
