# encoding: utf-8

# File:	include/novell-ncpserver/wizards.ycp
# Package:	Configuration of ncpserver
# Summary:	Wizards definitions
# Authors:	Stephen T. Bunch <sbunch@novell.com>
#
# $Id: wizards.ycp,v 1.1.2.2 2004/12/03 00:04:42 sbunch Exp $
module Yast
  module NovellNcpserverWizardsInclude
    def initialize_novell_ncpserver_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-ncpserver"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-ncpserver/complex.rb"
      Yast.include include_target, "novell-ncpserver/dialogs.rb"
    end

    # Main workflow of the ncpserver configuration
    # @return sequence result
    def MainSequence
      aliases = { "tree" => lambda { EdirHostDialog() } }

      sequence = {
        "ws_start" => "tree",
        "tree"     => { :abort => :abort, :next => :next, :skip => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of ncpserver
    # @return sequence result
    def NcpserverSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("ncpserver")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of ncpserver but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def NcpserverAutoSequence
      # Initialization dialog caption
      caption = _("Ncpserver Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("ncpserver")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
